@@ -200,12 +200,14 @@ def SigProfilerSimulator (project, project_path, genome, contexts, exome=None, s
 		os.makedirs(project_path + "logs/")
 
 	if os.path.exists(error_file):
-		os.system("rm " + error_file)
+		# os.system("rm " + error_file)
+		os.remove(error_file)
 	if os.path.exists(log_file):
-		os.system("rm " + log_file)
+		# os.system("rm " + log_file)
+		os.remove(log_file)
 
 
-	# sys.stderr = open(error_file, 'w')
+	sys.stderr = open(error_file, 'w')
 	log_out = open(log_file, 'w')
 	log_out.write("THIS FILE CONTAINS THE METADATA ABOUT SYSTEM AND RUNTIME\n\n\n")
 	log_out.write("-------System Info-------\n")
@@ -228,8 +230,8 @@ def SigProfilerSimulator (project, project_path, genome, contexts, exome=None, s
 	# Ensures that the chromosome strings are saves properly:
 	chromosome_string_path, ref_dir = matRef.reference_paths(genome)
 	if os.path.exists(chromosome_string_path) == False or len(os.listdir(chromosome_string_path)) <= len(chromosomes):
-		print("     The chromosome strings were not saved properly or have not been created yet. Rerun the SigProfilerMatrixGenerator install script.")
-
+		print("     The chromosome strings were not saved properly or have not been created yet. Please refer to the SigProfilerMatrixGenerator README for installation instructions:\n\thttps://github.com/AlexandrovLab/SigProfilerMatrixGenerator")
+		sys.exit()
 	# Ensures that the chromosome proportions are saved: 
 	if os.path.exists(chromosome_string_path + genome + "_proportions.txt") == False:
 		print("     Chromosome proportion file does not exist. Creating now...", end='')
@@ -488,6 +490,8 @@ def SigProfilerSimulator (project, project_path, genome, contexts, exome=None, s
 	print("Simulation completed\nJob took " , run_time, " seconds", file=log_out)
 	print("Simulation completed\nJob took " , run_time, " seconds")
 	log_out.close()
+	sys.stderr.close()
+
 	
 
 
